"""Tests ace package."""

import pytest


def test_run_ace():
    """Tests ace to see if it runs."""
    from acepython import run_ace
    from astropy import units as u
    import numpy as np

    temperature = np.linspace(3000, 1000, 100) << u.K
    pressure = np.logspace(6, -2, 100) << u.bar

    species, mix_profile, mu_profile = run_ace(
        temperature,
        pressure,
    )

    assert mix_profile.shape[-1] == pressure.shape[-1]
    assert mu_profile.shape[-1] == pressure.shape[-1]

    np.testing.assert_array_almost_equal(np.sum(mix_profile, axis=0), 1.0)


# test if taurex installed
# if not, skip the test


# @pytest.mark.skip(reason="This test is not yet implemented.")
def test_taurex3():
    """Tests taurex3 to see if it runs."""
    taurex = pytest.importorskip("taurex")

    from acepython.taurex3 import ACEChemistry
    from astropy import units as u
    import numpy as np

    temperature = np.linspace(3000, 1000, 100)
    pressure = np.logspace(6, -2, 100)

    tau = ACEChemistry()
    tau.initialize_chemistry(temperature_profile=temperature, pressure_profile=pressure)

    assert tau.mixProfile.shape[-1] == pressure.shape[-1]
    assert tau.muProfile.shape[-1] == pressure.shape[-1]


def test_taurex3_c_ratio():
    """Tests taurex3 to see if it runs."""
    taurex = pytest.importorskip("taurex")

    from acepython.taurex3 import ACEChemistry
    from astropy import units as u
    import numpy as np

    temperature = np.linspace(3000, 1000, 100)
    pressure = np.logspace(6, -2, 100)

    tau = ACEChemistry(C_ratio=0.5)
    tau.initialize_chemistry(temperature_profile=temperature, pressure_profile=pressure)
    assert tau._ratios[0] == 0.5
    assert tau.mixProfile.shape[-1] == pressure.shape[-1]
    assert tau.muProfile.shape[-1] == pressure.shape[-1]



"""Nox sessions."""
import os
import shlex
import shutil
import sys
from pathlib import Path
from textwrap import dedent

import nox

from nox import session

package = "acepython"
python_versions = ["3.13", "3.12", "3.11", "3.10"]
nox.needs_version = ">= 2021.6.6"
nox.options.sessions = (
    "pre-commit",
    "safety",
    "mypy",
    "tests",
    "typeguard",
    "xdoctest",
    "docs-build",
)


@session(python=python_versions)
def mypy(session) -> None:
    """Type-check using mypy."""
    args = session.posargs or ["src", "tests"]
    session.install(".")
    session.install("mypy", "pytest")
    session.run("mypy", *args)
    if not session.posargs:
        session.run("mypy", f"--python-executable={sys.executable}", "noxfile.py")


@session(python=python_versions)
def tests(session) -> None:
    """Run the test suite."""
    session.install(".")
    session.install("coverage[toml]", "pytest", "pygments")
    try:
        session.run("coverage", "run", "--parallel", "-m", "pytest", *session.posargs)
    finally:
        if session.interactive:
            session.notify("coverage", posargs=[])


@session(python=python_versions[0])
def coverage(session) -> None:
    """Produce the coverage report."""
    args = session.posargs or ["report"]

    session.install("coverage[toml]")

    if not session.posargs and any(Path().glob(".coverage.*")):
        session.run("coverage", "combine")

    session.run("coverage", *args)
